@@ -2,7 +2,9 @@ import os
 import sys
 import argparse
 from datetime import datetime
+from now import config
 
+CONFIG_PATH = "~/.nowrc"
 OUTPUT_PATH = "~/.now.txt"
 
 
@@ -13,7 +15,14 @@ def make_parser():
 
 
 def get_output_file():
-    path = os.path.expanduser(OUTPUT_PATH)
+    nowrc = config.Nowrc.from_file(os.path.expanduser(CONFIG_PATH))
+    path = nowrc['write_to'] or OUTPUT_PATH
+    path = os.path.expanduser(path)
+    abspath = os.path.abspath(path)
+    if path != abspath:
+        sys.stderr.write("Error: write_to parameter in ~/.nowrc "
+                         "should be an absolute path.\n")
+        return None
     output = open(path, 'a+b')
     return output
 
@@ -24,12 +33,13 @@ def _main(args, encoding="utf-8"):
     parser = make_parser()
     parsed, extra = parser.parse_known_args(args)
     if not parsed.message and not extra:
-        sys.stderr.write("You forgot to say what you're doing.\n"
-                         .encode(encoding))
+        sys.stderr.write("You forgot to say what you're doing.\n")
         return 1
     message = "{0} {1}".format(" ".join(parsed.message), " ".join(extra))
     line = "{0} {1}".format(timestamp, message)
     output = get_output_file()
+    if output is None:
+        return 1
     with output:
         output.write(line.encode(encoding))
         output.write(b'\n')
